@@ -36,11 +36,14 @@ from datalad.utils import try_multiple
 from datalad.utils import assure_list
 
 from datalad.downloaders.providers import Providers
-from datalad.api import create
+from datalad.api import (
+    create,
+    Dataset,
+)
 from datalad.support.gitrepo import GitRepo, _normalize_path
 from datalad.support.annexrepo import AnnexRepo
+from datalad.support.external_versions import external_versions
 from datalad.support.stats import ActivityStats
-from datalad.support.versions import get_versions
 from datalad.support.exceptions import AnnexBatchCommandError
 from datalad.support.network import get_url_straight_filename
 from datalad.support.network import get_url_disposition_filename
@@ -51,9 +54,11 @@ from datalad_crawler.pipeline import initiate_pipeline_config
 from datalad_crawler.dbs.files import PhysicalFileStatusesDB
 from datalad_crawler.dbs.files import JsonFileStatusesDB
 from datalad_crawler.dbs.versions import SingleVersionDB
+from datalad_crawler.support.versions import get_versions
 from datalad.customremotes.base import init_datalad_remote
 from datalad.dochelpers import exc_str
 
+from inspect import signature
 from logging import getLogger
 
 lgr = getLogger('datalad.crawl.annex')
@@ -125,7 +130,14 @@ class initiate_dataset(object):
 
         initopts = []
         if self.branch is not None:
-            initopts += ["-b", self.branch]
+            # init -b was introduced in git 2.28
+            if external_versions['cmd:git'] < '2.28':
+                if self.branch != 'master':  # AFAIK t would be the default one anyways
+                    raise NotImplementedError(
+                        "Cannot specify branch with git < 2.28. Current git: %s"
+                        % external_versions['cmd:git'])
+            else:
+                initopts += ["-b", self.branch]
 
         ds = create(path=path, force=False, initopts=initopts)
 
@@ -1256,17 +1268,36 @@ class Annexificator(object):
             stats = data.get('datalad_stats', ActivityStats())
             archive = self._get_fpath(data, stats)
             # TODO: may be adjust annex_options
-            annex = add_archive_content(
-                archive, annex=self.repo,
-                key=False, commit=commit, allow_dirty=True,
-                annex_options=self.options,
-                stats=stats,
-                **aac_kwargs
-            )
+
+            # an interoperability hack: add-archive-content became a dataset
+            # method in datalad#6105. Adjust the function call accordingly:
+            if 'dataset' in str(signature(add_archive_content)):
+                add_archive_content(
+                    archive,
+                    dataset=Dataset(self.repo.path),
+                    key=False,
+                    commit=commit,
+                    allow_dirty=True,
+                    annex_options=self.options,
+                    stats=stats,
+                    **aac_kwargs
+                )
+            else:
+                # add-archive-content is not a dataset method
+                annex = add_archive_content(archive,
+                                            annex=self.repo,
+                                            key = False,
+                                            commit = commit,
+                                            allow_dirty = True,
+                                            annex_options=self.options,
+                                            stats=stats,
+                                            **aac_kwargs
+                                            )
+                assert (annex is self.repo)  # must be the same annex, and no
+                # new one created to propagate statistics from this call into
+                # commit msg since we commit=False here we update data with
+                # stats which gets a new instance if wasn't present
             self._states.add("Added files from extracted archives")
-            assert (annex is self.repo)  # must be the same annex, and no new one created
-            # to propagate statistics from this call into commit msg since we commit=False here
-            # we update data with stats which gets a new instance if wasn't present
             yield updated(data, {'datalad_stats': stats})
 
         return _add_archive_content
