@@ -11,8 +11,8 @@ from datalad.support.annexrepo import AnnexRepo
 
 from datalad.utils import chpwd
 from datalad.utils import swallow_logs
-from datalad.tests.utils import eq_, assert_not_equal, ok_, assert_raises
-from datalad.tests.utils import with_tempfile
+from datalad.tests.utils_pytest import eq_, assert_not_equal, ok_, assert_raises
+from datalad.tests.utils_pytest import with_tempfile
 
 from ..nda import pipeline, bucket_pipeline, collection_pipeline
 
@@ -21,7 +21,7 @@ lgr = getLogger('datalad.crawl.tests')
 
 
 @with_tempfile(mkdir=True)
-def test_smoke_pipelines(d):
+def test_smoke_pipelines(d=None):
     # Just to verify that we can correctly establish the pipelines
     AnnexRepo(d, create=True)
     with chpwd(d):
